==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/pt_PT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
    "Storage invalid" : "Armazenamento inválido",
    "Unknown error" : "Erro desconhecido",
    "All files" : "Todos os ficheiros",
    "Saved" : "Guardado",
    "There was an error saving" : "Ocorreu um erro ao guardar",
    "File could not be found" : "Não foi possível encontrar o ficheiro",
    "Home" : "Início",
    "Close" : "Fechar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "Upload cancelled." : "Envio cancelado.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não é possível enviar {filename}, porque este é uma diretoria ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente, está a enviar {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "A pasta pretendida \"{dir}\" não existe mais",
    "Target folder does not exist any more" : "A pasta pretendida já não existe",
    "Not enough free space" : "Não há espaço livre suficiente",
    "Uploading..." : "A enviar...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Envio de ficheiro em progresso. Se deixar a página agora, irá cancelar o envio.",
    "Actions" : "Ações",
    "Download" : "Transferir",
    "Rename" : "Renomear",
    "Delete" : "Eliminar",
    "Disconnect storage" : "Desligue o armazenamento",
    "Unshare" : "Cancelar partilha",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar a informação para o ficheiro \"{file}\"",
    "Files" : "Ficheiros",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Não é possível determinar a data",
    "Invalid path" : "Caminho inválido",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", destino já existe",
    "Could not move \"{file}\"" : "Não foi possivel mover o ficheiro \"{file}\"",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", este já não existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está em utilização na pasta \"{dir}\". Por favor, escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\", porque esta já existe",
    "Error deleting file \"{fileName}\"." : "Erro ao eliminar o ficheiro \"{fileName}\".",
    "No entries in this folder match {filter}" : "Nenhuma entrada nesta pasta corresponde a {filter}",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n escondido","incluindo %n escondidos"],
    "You don’t have permission to upload or create files here" : "Não tem permissão para enviar ou criar ficheiros aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["A enviar %n ficheiro","A enviar %n ficheiros"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" tem um tipo de ficheiro/extensão proibido.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O armazenamento de {owner} está cheio. Os ficheiros já não podem ser atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu armazenamento está cheio, os ficheiros já não podem ser atualizados ou sincronizados.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento de {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu armazenamento está quase cheio ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corresponde a '{filter}'","correspondem a '{filter}'"],
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Nos Favoritos",
    "Favorite" : "Favorito",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Hiperligação privada: Apenas as pessoas que têm acesso ao ficheiro ou pasta podem utiliza-los. Use-a como uma hiperligação para rederecionar pessoas a ficheiros dentro de partilhas.",
    "Folder" : "Pasta",
    "New folder" : "Nova pasta",
    "{newname} already exists" : "{newname} já existe",
    "Upload" : "Enviar",
    "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as etiquetas",
    "A new file or folder has been <strong>created</strong>" : "Foi <strong>criado</strong> um novo ficheiro ou pasta",
    "A file or folder has been <strong>changed</strong>" : "Foi <strong>alterado</strong> um ficheiro ou pasta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite as notificações sobre a criação e alterações para os seus <strong>ficheiros favoritos</strong> <em>(apenas Emissão)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Foi <strong>eliminado</strong> um ficheiro ou pasta",
    "A file or folder has been <strong>restored</strong>" : "Foi <strong>restaurado</strong> um ficheiro ou pasta",
    "You created %1$s" : "Criou %1$s",
    "%2$s created %1$s" : "%2$s criou %1$s",
    "%1$s was created in a public folder" : "%1$s foi criado numa pasta pública",
    "You changed %1$s" : "Alterou %1$s",
    "%2$s changed %1$s" : "%2$s alterou %1$s",
    "You deleted %1$s" : "Eliminou %1$s",
    "%2$s deleted %1$s" : "%2$s eliminou %1$s",
    "You restored %1$s" : "Restaurou %1$s",
    "%2$s restored %1$s" : "%2$s restaurou %1$s",
    "Changed by %2$s" : "Alterado por %2$s",
    "Deleted by %2$s" : "Eliminado por %2$s",
    "Restored by %2$s" : "Restaurado por %2$s",
    "Upload (max. %s)" : "Envio (máx. %s)",
    "File handling" : "Utilização do ficheiro",
    "Maximum upload size" : "Tamanho máximo de envio",
    "max. possible: " : "Máx. possível: ",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com o PHP-FPM poderá demorar 5 minutos até que as alterações sejam aplicadas.",
    "Missing permissions to edit from here." : "Faltam permissões para editar a partir daqui.",
    "Settings" : "Configurações",
    "Show hidden files" : "Mostrar ficheiros ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilize este endereço para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">aceder aos seus ficheiros via WebDAV</a>",
    "No files in here" : "Nenhuns ficheiros aqui",
    "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Select all" : "Selecionar todos",
    "Upload too large" : "Envio muito grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que está a tentar enviar excedem o tamanho máximo para os envios de ficheiro neste servidor.",
    "No favorites" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
    "Text file" : "Ficheiro de Texto",
    "New text file.txt" : "Novo texto ficheiro.txt",
    "Unknown user" : "Utilizador desconhecido"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/pt_PT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
    "Storage invalid" : "Armazenamento inválido",
    "Unknown error" : "Erro desconhecido",
    "All files" : "Todos os ficheiros",
    "File could not be found" : "Não foi possível encontrar o ficheiro",
    "Home" : "Início",
    "Close" : "Fechar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "Upload cancelled." : "Envio cancelado.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não é possível enviar {filename}, porque este é uma diretoria ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente, está a enviar {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "A pasta de destino \"{dir}\" já não existe",
    "Target folder does not exist any more" : "A pasta de destino já não existe",
    "Not enough free space" : "Espaço livre insuficiente",
    "Uploading..." : "A enviar...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Envio de ficheiro em progresso. Se deixar a página agora, irá cancelar o envio.",
    "Actions" : "Ações",
    "Download" : "Transferir",
    "Rename" : "Renomear",
    "Delete" : "Eliminar",
    "Disconnect storage" : "Desligue o armazenamento",
    "Unshare" : "Cancelar partilha",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar a informação para o ficheiro \"{file}\"",
    "Files" : "Ficheiros",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Não é possível determinar a data",
    "Invalid path" : "Caminho inválido",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
    "group" : "grupo",
    "Remote share" : "Partilha remota",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", destino já existe",
    "Could not move \"{file}\"" : "Não foi possivel mover o ficheiro \"{file}\"",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", este já não existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está em utilização na pasta \"{dir}\". Por favor, escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\", porque esta já existe",
    "Error deleting file \"{fileName}\"." : "Erro ao eliminar o ficheiro \"{fileName}\".",
    "No entries in this folder match {filter}" : "Nenhuma entrada nesta pasta corresponde a {filter}",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n escondido","incluindo %n escondidos"],
    "You don’t have permission to upload or create files here" : "Não tem permissão para enviar ou criar ficheiros aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["A enviar %n ficheiro","A enviar %n ficheiros"],
    "New" : "Novo",
    "Unknown user" : "Utilizador desconhecido",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" tem um tipo de ficheiro/extensão proibido.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O armazenamento de {owner} está cheio. Os ficheiros já não podem ser atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu armazenamento está cheio, os ficheiros já não podem ser atualizados ou sincronizados.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento de {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu armazenamento está quase cheio ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corresponde a '{filter}'","correspondem a '{filter}'"],
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Nos Favoritos",
    "Favorite" : "Favorito",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Hiperligação privada: Apenas as pessoas que têm acesso ao ficheiro ou pasta podem utiliza-los. Use-a como uma hiperligação para rederecionar pessoas a ficheiros dentro de partilhas.",
    "Folder" : "Pasta",
    "New folder" : "Nova pasta",
    "{newname} already exists" : "{newname} já existe",
    "Upload" : "Enviar",
    "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as etiquetas",
    "A new file or folder has been <strong>created</strong>" : "Foi <strong>criado</strong> um novo ficheiro ou pasta",
    "A file or folder has been <strong>changed</strong>" : "Foi <strong>alterado</strong> um ficheiro ou pasta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite as notificações sobre a criação e alterações para os seus <strong>ficheiros favoritos</strong> <em>(apenas Emissão)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Foi <strong>eliminado</strong> um ficheiro ou pasta",
    "A file or folder has been <strong>restored</strong>" : "Foi <strong>restaurado</strong> um ficheiro ou pasta",
    "You created %1$s" : "Criou %1$s",
    "%2$s created %1$s" : "%2$s criou %1$s",
    "%1$s was created in a public folder" : "%1$s foi criado numa pasta pública",
    "You changed %1$s" : "Alterou %1$s",
    "%2$s changed %1$s" : "%2$s alterou %1$s",
    "You deleted %1$s" : "Eliminou %1$s",
    "%2$s deleted %1$s" : "%2$s eliminou %1$s",
    "You restored %1$s" : "Restaurou %1$s",
    "%2$s restored %1$s" : "%2$s restaurou %1$s",
    "Changed by %2$s" : "Alterado por %2$s",
    "Deleted by %2$s" : "Eliminado por %2$s",
    "Restored by %2$s" : "Restaurado por %2$s",
    "Upload (max. %s)" : "Envio (máx. %s)",
    "Settings" : "Configurações",
    "Show hidden files" : "Mostrar ficheiros ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilize este endereço para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">aceder aos seus ficheiros via WebDAV</a>",
    "No files in here" : "Nenhuns ficheiros aqui",
    "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Select all" : "Selecionar todos",
    "Upload too large" : "Envio muito grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que está a tentar enviar excedem o tamanho máximo para os envios de ficheiro neste servidor.",
    "No favorites" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
    "Text file" : "Ficheiro de Texto",
    "New text file.txt" : "Novo texto ficheiro.txt"
},
"nplurals=2; plural=(n != 1);");
